PCB Environment: rewards::RouteLength Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
rewards::RouteLength Class Reference
Inheritance diagram for rewards::RouteLength:

## Public Member Functions
virtual void | setContext (const PCBoard &) override
Reward | operator() (const Connection &, RouterResult *=0) const override
Reward | operator() (const std::vector< Connection * > &, RouterResult *=0) const override
Reward | operator() (int unrouted) const override

## Static Public Member Functions
static RouteLength * | create (PyObject *)
Static Public Member Functions inherited from RewardFunction
static RewardFunction * | create (PyObject *)

## Member Function Documentation

## ◆ operator()() [1/3]

Reward rewards::RouteLength::operator() | ( | const Connection & | ,
|  | RouterResult * | = 0 ) const
| overridevirtual

Implements RewardFunction.

## ◆ operator()() [2/3]

Reward rewards::RouteLength::operator() | ( | const std::vector< Connection * > & | ,
|  | RouterResult * | = 0 ) const
| overridevirtual

Implements RewardFunction.

## ◆ operator()() [3/3]

Reward rewards::RouteLength::operator() | ( | int | unrouted | ) | const
| overridevirtual

Implements RewardFunction.

## ◆ setContext()

virtual void rewards::RouteLength::setContext | ( | const PCBoard & |  | ) |
| overridevirtual

Reimplemented from RewardFunction.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Reward.hpp